
"""
_zt_core module
-----------------

The module contains the core base classes for the zttt package.
"""


from .zt_base_board import ZTBaseBoard
from .zt_engine_first import ZTEngineFirst
from .zt_player_first import ZTPlayerFirst
